-----------------------------------------------------------------------------------------------
-- Client Lua Script for DoubleGatherer
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
 
-----------------------------------------------------------------------------------------------
-- DoubleGatherer Module Definition
-----------------------------------------------------------------------------------------------
local DoubleGatherer = {} 


-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function DoubleGatherer:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here

    return o
end

function DoubleGatherer:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 

-----------------------------------------------------------------------------------------------
-- DoubleGatherer OnLoad
-----------------------------------------------------------------------------------------------
function DoubleGatherer:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("DoubleGatherer.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
end

-----------------------------------------------------------------------------------------------
-- DoubleGatherer OnDocLoaded
-----------------------------------------------------------------------------------------------
function DoubleGatherer:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "DoubleGathererForm", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		
	    self.wndMain:Show(false, true)
		Apollo.RegisterEventHandler("TargetUnitChanged", "OnTargetUnitChanged", self)
		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)


		-- Do additional Addon initialization here
		self.GatheringTypes = {
		[116] = CraftingLib.GetTradeskillInfo(15).strName, -- Survivalist
		[117] = CraftingLib.GetTradeskillInfo(18).strName, -- Relic Hunter
		[106] = CraftingLib.GetTradeskillInfo(13).strName, -- Mining
		}
		
		self.Locale = 1
		
		local strCancel = Apollo.GetString(1)
		if strCancel == "Abbrechen" then
			self.Locale = 2
		elseif strCancel == "Annuler" then
			self.Locale = 3
		else
			self.Locale = 1
		end

		
		

	end
end

-----------------------------------------------------------------------------------------------
-- DoubleGatherer Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here


-----------------------------------------------------------------------------------------------
-- DoubleGathererForm Functions
-----------------------------------------------------------------------------------------------
-- when the OK button is clicked
function DoubleGatherer:OnOK()
	self.wndMain:Close() -- hide the window
end

-- when the Cancel button is clicked
function DoubleGatherer:OnCancel()
	self.wndMain:Close() -- hide the window
end


-----------------------------------------------------------------------------------------------
-- DoubleGatherer Instance
-----------------------------------------------------------------------------------------------
local DoubleGathererInst = DoubleGatherer:new()
DoubleGathererInst:Init()


function DoubleGatherer:OnTargetUnitChanged()
if GameLib.GetPlayerUnit() == nil then return end
local target = GameLib.GetPlayerUnit():GetTarget()
	if target and target:GetType() == "Harvest" then
		local harvestType = GameLib.GetTargetUnit():GetHarvestRequiredTradeskillName()
		local tool = self:GetEquippedTool(GameLib.GetPlayerUnit():GetEquippedItems())
		if harvestType and not tool or self.GatheringTypes[tool:GetItemCategory()] ~= harvestType then		
			self:TryToEquipTool(harvestType)
		end
	end
end

function DoubleGatherer:GetEquippedTool(equippedItems)	
	for i,v in ipairs(equippedItems) do		
		if v:GetSlot() == 6 then
			return v 
		end
	end
	return nil 
end

function DoubleGatherer:TryToEquipTool(harvestType)
	local tInvItems = GameLib.GetPlayerUnit():GetInventoryItems()

	for idx,item in pairs(tInvItems) do
		if item.itemInBag then
			local catName = item.itemInBag:GetItemCategoryName()
			if self:CompareNames(catName,harvestType) then
				if GameLib.CanEquipBagItem(idx) then
					GameLib.EquipBagItem(item.nBagSlot+1)
				end
			end
		end
	end
end

function DoubleGatherer:CompareNames(catName,harvestType)
	if harvestType == nil then
		return false
	end
	if self.Locale==1 and catName == harvestType .." Tool" then
		return true
	elseif self.Locale==2 and (catName == harvestType .."werkzeug" or catName == harvestType .."-Werkzeug") then
		return true
	elseif self.Locale==3 then
		if (harvestType=="Adepte de la survie" and catName == "Outil d'adepte de la survie") then
			return true
		elseif (harvestType=="Chasseur de reliques" and catName == "Outil de reliques") then
			return true
		elseif catName == "Extraction minière" and harvestType=="Mineur" then
			return true
		end
	end
	return false
end